@@ -28,7 +28,7 @@ class SJXLIterator(object):
         self._myCount = 0
 
     ## NB becomes __next__ in Python 3.x don't know if Python 2.7 has a wrapper here
-    def next(self):
+    def __next__(self):
         if self._myCount < len(self._mySubJobs):
             returnable = self._mySubJobs[self._myCount]
             self._myCount += 1
@@ -114,6 +114,24 @@ class SubJobXMLList(GangaObject):
         """
         self._cachedJobs = obj
 
+    def appendJobs(self, job_dict, parent):
+        """
+        A method to append jobs to an existing SubJobXMLList
+        Args:
+            job_dict (dict): A dict of integer job keys and job items to append
+            parent : Parent job object
+        """
+        #First check the id is not already in the job cache
+        for k in job_dict.keys():
+            if k in self._cachedJobs.keys():
+                raise RepositoryError("Subjob key %s is already in the subjob XML cache!" % k)
+        #Now set the parent for the new subjobs 
+        for k,v in job_dict.items():
+            v._setParent(parent)
+        #Now add the new subjobs to the SubJobXMLList cache and flush it to disk
+        self._cachedJobs.update(job_dict)
+        self.flush(True)
+
     def isLoaded(self, subjob_id):
         """Has the subjob been loaded? True/False
         Args:
@@ -130,7 +148,7 @@ class SubJobXMLList(GangaObject):
                 from GangaCore.Core.GangaRepository.PickleStreamer import from_file
 
                 try:
-                    index_file_obj = open(index_file, "r" )
+                    index_file_obj = open(index_file, "rb" )
                     self._subjobIndexData = from_file( index_file_obj )[0]
                 except IOError as err:
                     self._subjobIndexData = None
@@ -195,9 +213,9 @@ class SubJobXMLList(GangaObject):
 
         all_caches = {}
         if ignore_disk:
-            range_limit = self._cachedJobs.keys()
+            range_limit = list(self._cachedJobs.keys())
         else:
-            range_limit = range(len(self))
+            range_limit = list(range(len(self)))
 
         for sj_id in range_limit:
             if sj_id in self._cachedJobs:
@@ -217,7 +235,7 @@ class SubJobXMLList(GangaObject):
         try:
             from GangaCore.Core.GangaRepository.PickleStreamer import to_file
             index_file = path.join(self._jobDirectory, self._subjob_master_index_name)
-            index_file_obj = open(index_file, "w")
+            index_file_obj = open(index_file, "wb")
             to_file(all_caches, index_file_obj)
             index_file_obj.close()
         ## Once I work out what the other exceptions here are I'll add them
@@ -507,9 +525,9 @@ class SubJobXMLList(GangaObject):
         from GangaCore.Core.GangaRepository.VStreamer import to_file
 
         if ignore_disk:
-            range_limit = self._cachedJobs.keys()
+            range_limit = list(self._cachedJobs.keys())
         else:
-            range_limit = range(len(self))
+            range_limit = list(range(len(self)))
 
         for index in range_limit:
             if index in self._cachedJobs:
