@@ -7,6 +7,7 @@ import subprocess
 import os
 import urllib
 import os
+import tempfile
 
 def checkSingularity():
     """Check whether Singularity is installed and the current user has right to access
@@ -67,27 +68,37 @@ def installUdocker(location='~'):
 
         Return value: True (If Success) or False"""
 
-    fname = os.path.join(os.path.expanduser(location),"udocker")
-    url = "https://raw.githubusercontent.com/indigo-dc/udocker/master/udocker.py"
+    location = os.path.expanduser(location)
+    
+    tarball = "udocker-1.3.0.tar.gz"
+    url = "https://github.com/indigo-dc/udocker/releases/download/v1.3.0/"+tarball
 
     import ssl
     context = ssl._create_unverified_context()
-    try:
-        with urlopen(url, context=context) as response, open(fname, 'wb') as out_file:
-            data = response.read()
-            out_file.write(data)
-    except:
-        returnCode = subprocess.check_call(['curl', '-k', url], stdout=open(fname, 'wb'))
-        if (returnCode != 0):
-            raise OSError('Error downloading uDocker')
 
-    subprocess.call(["chmod", "u+rx", fname])
-    udockerdir = os.path.join(location,'.udocker')
-    os.environ['UDOCKER_DIR']=udockerdir
-    os.makedirs(udockerdir)
-    with open(os.path.join(udockerdir,'udocker.conf'), 'w') as fconfig:
+    with tempfile.TemporaryDirectory() as tmpdirname:
+
+        fname = os.path.join(tmpdirname,tarball)
+
+        try:
+            with urlopen(url, context=context) as response, open(fname, 'wb') as out_file:
+                data = response.read()
+                out_file.write(data)
+        except:
+            returnCode = subprocess.check_call(['curl', '-k', url], stdout=open(fname, 'wb'))
+            if (returnCode != 0):
+                raise OSError('Error downloading uDocker')
+
+        subprocess.call(["tar", "-C", location, "-xzf", fname])
+
+        udockerdir = os.path.join(location,'.udocker')
+        os.environ['UDOCKER_DIR']=udockerdir
+        os.makedirs(udockerdir, exist_ok=True)
+        returnCode = subprocess.call([os.path.join(location,"udocker","udocker"), "install"])
+        if (returnCode != 0):
+            raise OSError('Error installing uDocker')
+
+    os.makedirs(os.path.join(location, 'udocker'), exist_ok=True)
+    with open(os.path.join(location,'udocker','udocker.conf'), 'w') as fconfig:
         fconfig.write('http_insecure = True')
-    returnCode = subprocess.call([fname, "install"])
-    if (returnCode != 0):
-        raise OSError('Error installing uDocker')
     print('UDocker Successfully installed')
