@@ -156,7 +156,7 @@ class DiracFile(IGangaFile):
     _name = "DiracFile"
     _exportmethods = ["get", "getMetadata", "getReplicas", 'getSubFiles', 'remove', 'removeReplica',
                       "replicate", 'put', 'locations', 'location', 'accessURL',
-                      '_updateRemoteURLs', 'hasMatchedFiles']
+                      '_updateRemoteURLs', 'hasMatchedFiles', 'getSize']
 
     _additional_slots = ['_have_copied', '_remoteURLs', '_storedReplicas']
 
@@ -226,6 +226,18 @@ class DiracFile(IGangaFile):
 
         return self.locations
 
+    def getSize(self):
+        """
+        Return the size of the DiracFile.
+        """
+
+        md = self.getMetadata()
+        size = md['Successful'][self.lfn]['Size']
+
+        return size
+
+
+
     def _setLFNnamePattern(self, lfn="", namePattern=""):
 
         if hasattr(self, 'defaultSE') and self.defaultSE != "":
@@ -284,10 +296,13 @@ class DiracFile(IGangaFile):
 
         return "DiracFile(namePattern='%s', lfn='%s', localDir='%s')" % (self.namePattern, self.lfn, self.localDir)
 
-    def getSubFiles(self):
+    def getSubFiles(self, process_wildcards = False):
         """
         Returns the subfiles for this instance
         """
+        if process_wildcards:
+            self.processWildcardMatches()
+
         if self.lfn:
             self.setLocation()
         return self.subfiles
