@@ -14,7 +14,7 @@ import datetime
 from functools import wraps
 from werkzeug.utils import secure_filename
 from werkzeug.security import generate_password_hash, check_password_hash
-from flask import Flask, request, jsonify, render_template, flash, redirect, url_for, session, send_file
+from flask import Flask, request, jsonify, render_template, flash, redirect, url_for, session, send_file, make_response
 from flask_login import login_user, login_required, logout_user, current_user, UserMixin
 from flask_sqlalchemy import SQLAlchemy
 from flask_login import LoginManager
@@ -259,10 +259,28 @@ def config_page():
 
     return render_template("config.html", title="Config", full_config_info=full_config_info, config_info=config_info)
 
-
+#Edit gangarc
+@gui.route("/config_edit",methods=["GET", "POST"])
+@login_required
+def edit_config_page():
+    """
+    Edit gangarc file from the GUI
+    """
+    gui_rc = gui.config["GANGA_RC"]
+    with open(gui_rc, "rt") as f:
+        ganga_config = f.read()
+    if request.method == 'POST':
+        config_ganga = request.form['config-data']
+        with open(gui_rc, 'w') as f1:
+            f1.write(str(config_ganga))
+        flash(".gangarc Edited", "success")
+        with open(gui_rc, "rt") as f2:
+            ganga_config = f2.read()
+    return render_template("config_edit.html", title="Edit gangarc", ganga_config=ganga_config)
+    
+@login_required
 # Create view
 @gui.route("/create", methods=["GET", "POST"])
-@login_required
 def create_page():
     """
     Handles create route of the GUI.
@@ -812,6 +830,19 @@ def credentials_page():
 
     return render_template('credentials.html', credential_info_list=credentials_info)
 
+@gui.route("/queue", methods=["GET"])
+@login_required
+def queue_page():
+    """
+    Displays queues information
+    """
+    try:
+        queue_info = query_internal_api("/internal/queue", "get")
+    except Exception as err:
+        flash(str(err), "danger")
+        return redirect(url_for("dashboard"))
+
+    return render_template('queue.html', queue_info_list=queue_info)
 
 # Plugins view
 @gui.route('/plugins')
@@ -1505,6 +1536,26 @@ def jobs_statistics_endpoint(current_api_user):
 
     return jsonify(statistics)
 
+@gui.route("/api/queue", methods=["GET"])
+@token_required
+def queue_endpoint(current_api_user):
+
+    try:
+        queue_info = query_internal_api("/internal/queue", "get")
+
+    except Exception as err:
+        return jsonify({"success": False, "message": str(err)}), 400
+
+    return jsonify(queue_info)
+
+@gui.route("/api/queue/chart", methods=["GET","POST"])
+def queue_chart_endpoint():
+
+    
+    chart_info = query_internal_api("/internal/queue/data", "get")
+    response = make_response(json.dumps(chart_info))
+    response.content_type = 'application/json'
+    return response
 
 # Job incomplete ids API - GET Method
 @gui.route("/api/jobs/incomplete_ids", methods=["GET"])
