@@ -8,6 +8,8 @@ import optparse
 import shutil
 import random
 
+from GangaCore.Utility.logging import getLogger
+logger = getLogger()
 
 class ND280Config:
 
@@ -30,12 +32,12 @@ class ND280Config:
 
     raw
 
-    module_list              = oaCalib oaRecon oaAnalysis
+    module_list     = oaCalib oaRecon oaAnalysis
 
     An example use:
 
-    >>> import ND280Configs
-    >>> cfg = ND280Configs.ND280Config('raw')
+    >>> import GangaND280.ND280Control.ND280Configs as CFG
+    >>> cfg = CFG.ND280Config('raw',{})
     >>> cfg.ListOptions()
 comment = v11r31-wg-bugaboo
 cmtpath = environment
@@ -75,7 +77,7 @@ inputfile =
         self.options_ignore=self.common_options_ignore
 
         if self.cfgtype == 'gnsetup':
-            self.options.update(self.genieSetupt_options)
+            self.options.update(self.genieSetup_options)
             self.options['genie_setup_script']=self.t2ksoftdir + '/GENIE/setup.sh'
         elif self.cfgtype == 'gnmc':
             self.options.update(self.genieMC_options)
@@ -96,7 +98,8 @@ inputfile =
         elif self.cfgtype == 'PG':
             self.options.update(self.pg_options)
         else:
-            raise 'ND280Configs: Not a recognised config type'
+            raise RuntimeError('ND280Configs: {} Not a reconised config type.'.format(self.cfgtype))
+
 
         self.options.update(extra_opts)
 
@@ -128,7 +131,8 @@ inputfile =
     raw_options={ 'midas_file':'',
                   'comment':'',
                   'event_select':'',
-                  'module_list':'oaCalib oaRecon oaAnalysis',
+                  'module_list_cmt':'oaCalib oaRecon oaAnalysis',
+                  'module_list_git':'eventCalib eventRecon eventAnalysis',
                   'version_number':'',
                   'inputfile':'',
                   'enable_modules':'',
@@ -147,7 +151,8 @@ inputfile =
 
     cosmicmc_options={   'stage':'base',
                          'nd280ver':'v11r31',
-                         'module_list':'cosmic nd280MC elecSim oaCalibMC oaCosmicTrigger',
+                         'module_list_cmt':'cosmic nd280MC elecSim oaCalibMC oaCosmicTrigger',
+                         'module_list_git':'cosmic nd280Geant4Sim detResponseSim eventCalibMC cosmicTriggerGeant4Sim',
                          'run_number':'0',
                          'subrun':'0',
                          'baseline':'2010-11',
@@ -168,7 +173,8 @@ inputfile =
 
     #### Sand MC
     sandmc_options={'stage':'neutMC',
-                'module_list':'sandPropagate nd280MC elecSim oaCalibMC oaRecon oaAnalysis',
+                'module_list_cmt':'sandPropagate nd280MC elecSim oaCalibMC oaRecon oaAnalysis',
+                'module_list_git':'sandPropagate nd280Geant4Sim detResponseSim eventCalibMC eventRecon eventAnalysis',
                 'neut_setup_script':'REPLACE_NEUTSETUP',
                 'neut_card':'REPLACE_NEUTCARD',
                 'flux_file':'REPLACE_FLUXFILE',
@@ -207,7 +213,8 @@ inputfile =
     sandmc_options_ignore={}
 
     #### MC
-    mc_options={'module_list':'nd280MC elecSim oaCalibMC oaRecon oaAnalysis',
+    mc_options={'module_list_cmt':'nd280MC elecSim oaCalibMC oaRecon oaAnalysis',
+                'module_list_git':'nd280Geant4Sim detResponseSim eventCalibMC eventRecon eventAnalysis',
                 'inputfile':'/lustre/ific.uv.es/sw/t2k.org/nd280Soft/nd280computing/processing_scripts/oa_nt_beam_90210013-0100_3ravbul66rum_numc_000_prod004magnet201011waterb.root',
                 'run_number':'90210000',
                 'subrun':'0',
@@ -254,7 +261,8 @@ inputfile =
                      'genie_paths':'',
                      'random_seed':''}
 
-    gncp_options = {'module_list':'oaCherryPicker nd280MC elecSim oaCalibMC oaRecon oaAnalysis',
+    gncp_options = {'module_list_cmt':'oaCherryPicker nd280MC elecSim oaCalibMC oaRecon oaAnalysis',
+                    'module_list_git':'selectEventSim nd280Geant4Sim detResponseSim eventCalibMC eventRecon eventAnalysis',
                     'run_number':'',
                     'subrun':'',
                     'comment':'',
@@ -280,7 +288,8 @@ inputfile =
     ### Particle Gun options
     pg_options = {'geo_baseline':'2010-02',
                   'p0d_water':'1',
-                  'module_list':'nd280MC elecSim oaCalibMC oaRecon oaAnalysis',
+                  'module_list_cmt':'nd280MC elecSim oaCalibMC oaRecon oaAnalysis',
+                  'module_list_git':'nd280Geant4Sim detResponseSim eventCalibMC eventRecon eventAnalysis',
                   'comment':'',
                   'num_events':'10000',
                   'mc_particle':'mu-',
@@ -296,27 +305,27 @@ inputfile =
     def CheckOptions(self):
         allOK=1
         ## Quick check to see if there are any blank options, only allowed for comment.
-        for k,v in self.options.iteritems():
+        for k,v in self.options.items():
             if not v:
                 if k in self.options_ignore:
                     continue
                 else:
-                    print 'Please ensure a value for ' + k + ' using the object.options[\'' + k + '\']'
+                    logger.info('Please ensure a value for ' + k + ' using the object.options[\'' + k + '\']')
                     allOK=0
 
         return allOK
 
     def ListOptions(self):
-        for k,v in self.options.iteritems():
-            print k + ' = ' + v
+        for k,v in self.options.items():
+            logger.info(k + ' = ' + v)
         return
 
     def SetOptions(self,options_in):
-        for k,v in options_in.iteritems():
+        for k,v in options_in.items():
             if k in self.options:
                 self.options[k]=v
             else:
-                print 'Option ' + k + ' not in list, ignoring.'
+                logger.info('Option ' + k + ' not in list, ignoring.')
 
     def CreateConfig(self):
         map = {
@@ -329,7 +338,7 @@ inputfile =
             creator = map[self.cfgtype]
             return creator()
         else:
-            raise 'ND280Configs: Not a reconised config type'
+            raise RuntimeError('ND280Configs: {} Not a reconised config type.'.format(self.cfgtype))
 
 
 
@@ -342,7 +351,7 @@ inputfile =
     def CreateRawCF(self):
 
         if not self.CheckOptions():
-            print 'ERROR please make sure all options stated above are entered'
+            logger.error('Please make sure all options stated above are entered')
             return ''
 
         configfile = ''
@@ -350,8 +359,12 @@ inputfile =
 
         ### Software Setup
         configfile += "[software]\n"
-        configfile += "cmtpath = " + self.options['cmtpath'] + "\n"
-        configfile += "cmtroot = " + self.options['cmtroot'] + "\n"
+        if 'cmtpath' in self.options:
+            configfile += "cmtpath = " + self.options['cmtpath'] + "\n"
+
+        if 'cmtroot' in self.options:
+            configfile += "cmtroot = " + self.options['cmtroot'] + "\n"
+
         configfile += "nd280ver = " + self.options['nd280ver'] + "\n\n"
 
         ### File naming
@@ -359,7 +372,7 @@ inputfile =
              self.options['comment'] =  self.options['nd280ver']
         configfile += "[filenaming]\n"
         if self.options['inputfile']:
-            print "version_number = " + self.options['version_number'] + "\n"
+            logger.info("version_number = " + self.options['version_number'] + "\n")
             configfile += "version_number = " + self.options['version_number'] + "\n"
         configfile += "comment = " + self.options['comment'] + "\n\n"
 
@@ -368,7 +381,11 @@ inputfile =
         configfile += "[configuration]\n"
         if not self.options['midas_file']:
             configfile += "inputfile = " + self.options['inputfile'] + "\n"
-        configfile += "module_list = " + self.options['module_list'] + "\n"
+
+        if self.options['nd280ver'][0] == 'v':
+            configfile += "module_list = " + self.options['module_list_cmt'] + "\n"
+        else:
+            configfile += "module_list = " + self.options['module_list_git'] + "\n"
 
         if self.options['db_time']:
             configfile += "database_rollback_date = " + self.options['db_time'] + "\n"
@@ -424,18 +441,17 @@ inputfile =
                 configfile += str(confline)+"\n"
             configfile += '\n'
 
-        #print configfile
         return configfile
 
     ######################## Cosmic Processing Config file
     def CreateCosmicMCCF(self):
 
         if not self.CheckOptions():
-            print 'ERROR please make sure all options stated above are entered'
+            logger.error('Please make sure all options stated above are entered')
             return ''
 
         if not self.options['stage'] in ['base','fgd','tript','all']:
-            print 'ERROR "stage" options should be one of',['base','fgd','tript','all']
+            logger.error('"stage" options should be one of',['base','fgd','tript','all'])
             return ''
 
         configfile = ''
@@ -444,17 +460,29 @@ inputfile =
 
         ### Software Setup
         configfile += "[software]\n"
-        configfile += "cmtpath = " + self.options['cmtpath'] + "\n"
-        configfile += "cmtroot = " + self.options['cmtroot'] + "\n"
+        if 'cmtpath' in self.options:
+            configfile += "cmtpath = " + self.options['cmtpath'] + "\n"
+
+        if 'cmtroot' in self.options:
+            configfile += "cmtroot = " + self.options['cmtroot'] + "\n"
+
         configfile += "nd280ver = " + self.options['nd280ver'] + "\n\n"
 
         ### Module list
         configfile += "[configuration]\n"
         if self.options['stage'] != 'base':
-            configfile += "module_list = oaRecon oaAnalysis\n"
+            if self.options['nd280ver'][0] == 'v':
+                configfile += "module_list = oaRecon oaAnalysis\n"
+            else:
+                configfile += "module_list = eventRecon eventAnalysis\n"
+
             configfile += "inputfile = " +  self.options['inputfile'] + "\n\n"
+
         else:
-            configfile += "module_list = " + self.options['module_list'] + "\n\n"
+            if self.options['nd280ver'][0] == 'v':
+                configfile += "module_list = " + self.options['module_list_cmt'] + "\n\n"
+            else:
+                configfile += "module_list = " + self.options['module_list_git'] + "\n\n"
 
         ### File naming
         if not  self.options['comment']:
@@ -505,11 +533,11 @@ inputfile =
     def CreateSandMCCF(self):
 
         if not self.CheckOptions():
-            print 'ERROR please make sure all options stated above are entered'
+            logger.error('Please make sure all options stated above are entered')
             return ''
 
         if not self.options['stage'] in ['neutMC','g4anal','neutSetup']:
-            print 'ERROR "stage" options should be one of',['neutMC','g4anal','neutSetup']
+            logger.error('"stage" options should be one of',['neutMC','g4anal','neutSetup'])
             return ''
 
         configfile = ''
@@ -523,10 +551,13 @@ inputfile =
         ### Module list
         configfile += "[configuration]\n"
         if self.options['stage'] == 'g4anal':
-            configfile += "module_list = sandPropagate nd280MC elecSim oaCalibMC  oaRecon oaAnalysis\n"
+            if self.options['nd280ver'][0] == 'v':
+                configfile += "module_list = sandPropagate nd280MC elecSim oaCalibMC  oaRecon oaAnalysis\n"
+            else:
+                configfile += "module_list = sandPropagate nd280Geant4Sim detResponseSim eventCalibMC  eventRecon eventAnalysis\n"
+
             configfile += "inputfile = " +  self.options['inputfile'] + "\n\n"
         else:
-            #configfile += "module_list = " + self.options['module_list'] + "\n\n"
             configfile += "module_list = neutMC\n\n"
 
         ### File naming
@@ -535,9 +566,9 @@ inputfile =
         configfile += "[filenaming]\n"
 
         thisrun = 90007000
-	if self.options['generator'] == "old-neut":
+        if self.options['generator'] == "old-neut":
             thisrun += 2000000
-	if self.options['generator'] == "anti-neut":
+        if self.options['generator'] == "anti-neut":
             thisrun = 80007000
         if self.options['generator'] == "genie" :
             thisrun += 1000000
@@ -545,7 +576,7 @@ inputfile =
         if self.options['beam'] == "beamc":
             thisrun += 300000
         else:
-            print "ERROR self.beam = " + self.beam + " is not supported!!!"
+            logger.error("self.beam = " + self.beam + " is not supported!!!")
             return ''
 
         if self.options['p0d_water_fill']: # water
