@@ -14,15 +14,14 @@ if not _after_bootstrap:
 
 def loadPlugins( config = {} ):
 
-   import ND280Dataset
-   import ND280Splitter
-   import ND280Control
-   import ND280Executable
-   import ND280RecoValidation
-   import ND280Skimmer
-   import Highland
-   import Tasks
-   import ND280TPCGasInteractions
-   import ND280Checkers
+   import GangaND280.ND280Dataset
+   import GangaND280.ND280Control
+   import GangaND280.ND280Executable
+   import GangaND280.ND280RecoValidation
+   import GangaND280.ND280Skimmer
+   import GangaND280.Highland
+   import GangaND280.Tasks
+   import GangaND280.ND280TPCGasInteractions
+   import GangaND280.ND280Checkers
 
    return None
